@@ -73,20 +73,20 @@ class MoovaHandler(object):
                     }
                 },
                 'to': {
-                    'street': instance.address.street,
-                    'number': instance.address.number,
+                    'street': instance.order.shipping_address.street,
+                    'number': instance.order.shipping_address.number,
                     'floor': '',
-                    'apartment': instance.address.unit,
-                    'city': instance.address.commune.name,
-                    'state': instance.address.commune.region.name,
-                    'postalCode': instance.address.commune.code,
+                    'apartment': instance.order.shipping_address.unit,
+                    'city': instance.order.shipping_address.commune.name,
+                    'state': instance.order.shipping_address.commune.region.name,
+                    'postalCode': instance.order.shipping_address.commune.code,
                     'country': api_settings.REMITENTE['COUNTRY'],
                     'instructions': instance.order.comment,
                     'contact': {
-                        'firstName': instance.address.customer.first_name,
-                        'lastName': instance.address.customer.last_name,
-                        'email': instance.address.customer.email,
-                        'phone': instance.address.customer.phone
+                        'firstName': instance.order.customer.first_name,
+                        'lastName': instance.order.customer.last_name,
+                        'email': instance.order.customer.email,
+                        'phone': instance.order.customer.phone
                     },
                     'message': ''
                 },
@@ -106,7 +106,7 @@ class MoovaHandler(object):
             }
 
             if hasattr(instance, 'order_details'):
-                payload['config']['items'] = [
+                payload['conf']['items'] = [
                     {
                         'item': {
                             'description': detail.product.name,
